use std::fmt::Display;
use warp::Filter;

mod commands;
use commands::{Query,Args,Command,Method};

fn json_api<S: Display + AsRef<str>>(user: S, query: Query) -> String {
    match query.command {
        Command::Zone => commands::zone(query),
        Command::Version => commands::version(query),
        _ => format!("Hello, {}! This command is unimplemented. Original query:\n{:?}", user, query)
    }
    //format!("Hello, world {}! You have attempted query:\n{:?}", &user, query)
}

#[tokio::main]
async fn main() {
    let api = warp::header::<String>("remote_user")
    .and(warp::path("api"))
    //.map(|user| "Hello, world!");
    
    // 16K max body size
    .and(warp::body::content_length_limit(1024 * 16))
    .and(warp::body::json())
    .map(|user, query| json_api(user, query));

    // Uncomment below to start hacking on the REST API
    //    .and(warp::path!("api" / String))
    //    .map(|user, command| format!("User {} wants to use command {}", user, command));

    warp::serve(api)
        .run(([127, 0, 0, 1], 3030))
        .await;
}
